==> vue-hooks-plus-1.1.7.tgz: package/lib/useRequest/plugins/useThrottlePlugin.js <==
"use strict";
const vue = require("vue");
const throttle = require("lodash/throttle");
const _interopDefaultLegacy = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const throttle__default = /* @__PURE__ */ _interopDefaultLegacy(throttle);
const useThrottlePlugin = (fetchInstance, { throttleWait, throttleLeading, throttleTrailing }) => {
  const throttledRef = vue.ref();
  const options = {};
  if ((throttleLeading == null ? void 0 : throttleLeading.value) !== void 0) {
    options.leading = throttleLeading.value;
  }
  if ((throttleTrailing == null ? void 0 : throttleTrailing.value) !== void 0) {
    options.trailing = throttleTrailing.value;
  }
  vue.watchEffect((onInvalidate) => {
    if (throttleWait) {
      const _originRunAsync = fetchInstance.runAsync.bind(fetchInstance);
      throttledRef.value = throttle__default.default(
        (callback) => {
          callback();
        },
        throttleWait,
        options
      );
      fetchInstance.runAsync = (...args) => {
        return new Promise((resolve, reject) => {
          var _a;
          (_a = throttledRef.value) == null ? void 0 : _a.call(throttledRef, () => {
            _originRunAsync(...args).then(resolve).catch(reject);
          });
        });
      };
      onInvalidate(() => {
        var _a;
        fetchInstance.runAsync = _originRunAsync;
        (_a = throttledRef.value) == null ? void 0 : _a.cancel();
      });
    }
  });
  if (!throttleWait) {
    return {};
  }
  return {
    onCancel: () => {
      var _a;
      (_a = throttledRef.value) == null ? void 0 : _a.cancel();
    }
  };
};
module.exports = useThrottlePlugin;

==> vue-hooks-plus-1.6.2.tgz: package/lib/useRequest/plugins/useThrottlePlugin.js <==
"use strict";
const vue = require("vue");
const throttle = require("lodash/throttle");
const _interopDefaultLegacy = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const throttle__default = /* @__PURE__ */ _interopDefaultLegacy(throttle);
const useThrottlePlugin = (fetchInstance, { throttleWait, throttleLeading, throttleTrailing }) => {
  const options = vue.computed(() => {
    const ret = {};
    if (vue.unref(throttleLeading) !== void 0) {
      ret.leading = vue.unref(throttleLeading);
    }
    if (vue.unref(throttleTrailing) !== void 0) {
      ret.trailing = vue.unref(throttleTrailing);
    }
    return ret;
  });
  const throttledRef = vue.computed(
    () => throttle__default.default(
      (callback) => {
        callback();
      },
      vue.unref(throttleWait),
      options.value
    )
  );
  vue.watchEffect((onInvalidate) => {
    if (vue.unref(throttleWait)) {
      const _originRunAsync = fetchInstance.runAsync.bind(fetchInstance);
      fetchInstance.runAsync = (...args) => {
        return new Promise((resolve, reject) => {
          var _a;
          (_a = throttledRef.value) == null ? void 0 : _a.call(throttledRef, () => {
            _originRunAsync(...args).then(resolve).catch(reject);
          });
        });
      };
      onInvalidate(() => {
        var _a;
        fetchInstance.runAsync = _originRunAsync;
        (_a = throttledRef.value) == null ? void 0 : _a.cancel();
      });
    }
  });
  if (!vue.unref(throttleWait)) {
    return {};
  }
  return {
    onCancel: () => {
      var _a;
      (_a = throttledRef.value) == null ? void 0 : _a.cancel();
    }
  };
};
module.exports = useThrottlePlugin;
